@@ -68,14 +68,14 @@ class InferDatetime:
                                                             'snowflake': 'dd/MM/yy hh:mi:ss',
                                                             'java': 'd/M/yy HH:mm:ss'},
 
-            # 2019-11-27 12:00:05.000
-            "^\\d{4}-\\d{1,2}-\\d{1,2} \\d{2}:\\d{2}:\\d{2}.\\d{3}$": {"C89": "%Y-%m-%d %H:%M:%S.%f",
-                                                                       'snowflake': 'yyyy-MM-dd HH:mm:ss.SS',
+            # 2019-11-27 12:00:05.000000
+            r"^\d{4}-\d{1,2}-\d{1,2} \d{2}:\d{2}:\d{2}.\d+$": {"C89": "%Y-%m-%d %H:%M:%S.%f",
+                                                                       'snowflake': 'yyyy-MM-dd HH:mm:ss.S',
                                                                        'java': "yyyy-MM-dd HH:mm:ss.SS"},
 
             # 2019-11-27T12:00:05.000Z
-            "^\\d{4}-\\d{1,2}-\\d{1,2}T\\d{2}:\\d{2}:\\d{2}.\\d{3}Z$": {"C89": "%Y-%m-%dT%H:%M:%S.%fZ",
-                                                                        'snowflake': 'yyyy-MM-ddTHH:mm:ss.SSZ',
+            r"^\d{4}-\d{1,2}-\d{1,2}T\d{2}:\d{2}:\d{2}.\d+Z": {"C89": "%Y-%m-%dT%H:%M:%S.%fZ",
+                                                                        'snowflake': 'yyyy-MM-ddTHH:mm:ss.SZ',
                                                                         'java': "yyyy-MM-dd'T'HH:mm:ss.SS'Z'"}
 
         }
